@@ -1,24 +1,24 @@
 
+#define PACKAGE_NAME "am-utils"
+#define PACKAGE_TARNAME "am-utils"
+#define PACKAGE_VERSION "6.1b5pre"
+#define PACKAGE_STRING "am-utils 6.1b5pre"
+#define PACKAGE_BUGREPORT "am-utils@am-utils.org"
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "freebsd4.6"
+#define HOST_OS "freebsd4.10"
 #define HOST_OS_NAME "freebsd4"
-#define HOST_OS_VERSION "4.6"
+#define HOST_OS_VERSION "4.10"
 #define HOST_ARCH "i386"
-#define HOST_NAME "FreeBSD-4.6.fsl.cs.sunysb.edu"
+#define HOST_NAME "a-freebsd410.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Wed Jun 26 17:14:08 GMT 2002"
+#define CONFIG_DATE "Thu Jan 13 17:14:31 EST 2005"
 #define PACKAGE_NAME "am-utils"
-#define PACKAGE_VERSION "6.1a6-pre"
-#define PACKAGE_BUGREPORT "amd-dev@am-utils.org"
+#define PACKAGE_VERSION "6.1b5pre"
+#define PACKAGE_BUGREPORT "am-utils@am-utils.org"
 #define PACKAGE "am-utils"
-#define VERSION "6.1a6-pre"
+#define VERSION "6.1b5pre"
 #define DEBUG 1
-#define HAVE_DLFCN_H 1
-#define HOST_HEADER_VERSION "4.6"
-#define YYTEXT_POINTER 1
-#define HAVE_LIBRPCSVC 1
-#define HAVE_ALLOCA 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
 #define HAVE_SYS_STAT_H 1
@@ -28,6 +28,11 @@
 #define HAVE_STRINGS_H 1
 #define HAVE_INTTYPES_H 1
 #define HAVE_UNISTD_H 1
+#define HAVE_DLFCN_H 1
+#define HOST_HEADER_VERSION "4.10"
+#define YYTEXT_POINTER 1
+#define HAVE_LIBRPCSVC 1
+#define HAVE_ALLOCA 1
 #define HAVE_UNISTD_H 1
 #define HAVE_FORK 1
 #define HAVE_VFORK 1
@@ -35,7 +40,6 @@
 #define HAVE_WORKING_FORK 1
 #define HAVE_WAIT3 1
 #define GETPGRP_VOID 1
-#define SETPGRP_VOID 1
 #define HAVE__SETERR_REPLY 1
 #define HAVE_BCMP 1
 #define HAVE_BCOPY 1
@@ -53,6 +57,7 @@
 #define HAVE_GETMNTINFO 1
 #define HAVE_GETPAGESIZE 1
 #define HAVE_GETTIMEOFDAY 1
+#define HAVE_MADVISE 1
 #define HAVE_MEMCMP 1
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
@@ -70,6 +75,7 @@
 #define HAVE_SETSID 1
 #define HAVE_SIGACTION 1
 #define HAVE_SIGNAL 1
+#define HAVE_SIGSUSPEND 1
 #define HAVE_SOCKET 1
 #define HAVE_STRCHR 1
 #define HAVE_STRCSPN 1
@@ -209,6 +215,7 @@
 #define HAVE_STRING_H 1
 #define HAVE_STRINGS_H 1
 #define HAVE_SYSLOG_H 1
+#define HAVE_TCPD_H 1
 #define HAVE_TIME_H 1
 #define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
@@ -218,7 +225,7 @@
 #define nfs_args_t struct nfs_args
 #define NFS_FH_FIELD fh
 #define am_nfs_fh nfs_fh
-#define am_nfs_fh3 nfs_fh3_freebsd3
+#define HAVE_FS_NFS3 1
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
 #define HAVE_FHANDLE 1
@@ -263,9 +270,11 @@
 #define HAVE_LONG_FILE_NAMES 1
 #define HAVE_UNISTD_H 1
 #define HAVE_RESTARTABLE_SYSCALLS 1
+#define HAVE_FD_SET_FDS_BITS 1
 #define HAVE_CDFS_ARGS_T_FLAGS 1
 #define HAVE_CDFS_ARGS_T_FSPEC 1
 #define HAVE_CDFS_ARGS_T_SSECTOR 1
+#define HAVE_PCFS_ARGS_T_DIRMASK 1
 #define HAVE_PCFS_ARGS_T_FSPEC 1
 #define HAVE_PCFS_ARGS_T_GID 1
 #define HAVE_PCFS_ARGS_T_MASK 1
@@ -282,14 +291,12 @@
 #define HAVE_STRUCT_IFADDRS_IFA_NEXT 1
 #define HAVE_STRUCT_SOCKADDR_SA_LEN 1
 #define HAVE_MAP_FILE 1
-#define HAVE_MAP_NDBM 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_PASSWD 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_MFS 1
 #define HAVE_FS_NFS 1
-#define HAVE_FS_NFS3 1
 #define HAVE_FS_PCFS 1
 #define HAVE_FS_UFS 1
 #define HAVE_FS_UNIONFS 1
@@ -355,3 +362,4 @@
 #define MNT2_CDFS_OPT_NORRIP 0x1
 #define HIDE_MOUNT_TYPE "nfs"
 #define USE_CONNECTED_NFS_SOCKETS 1
+#define HAVE_LIBWRAP 1
